#
# spec file for package kamoso
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gstnum  1.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kamoso
Version:        20.04.2
Release:        bp153.1.26
Summary:        Application to take pictures and videos using a webcam
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://projects.kde.org/kamoso
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules >= 0.0.9
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Purpose)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(libudev)
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       kirigami2
Recommends:     %{name}-lang
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif

%description
Kamoso is an application to take pictures and videos using a webcam.
The media can be pushed to some web services such as Facebook and
YouTube.

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%suse_update_desktop_file -r org.kde.kamoso Qt KDE AudioVideo Recorder

%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %{kf5_find_htmldocs}
%endif

%files
%license COPYING
%doc AUTHORS README TODO
%{_kf5_applicationsdir}/org.kde.kamoso.desktop
%{_kf5_bindir}/kamoso
%{_kf5_iconsdir}/hicolor/*/actions/*.*
%{_kf5_iconsdir}/hicolor/*/apps/kamoso.*
%doc %lang(en) %{_kf5_htmldir}/en/kamoso/
%{_kf5_appstreamdir}/org.kde.kamoso.appdata.xml
%{_libdir}/gstreamer-%{gstnum}/gstkamosoqt5videosink.so
%{_kf5_notifydir}/kamoso.notifyrc
%{_kf5_sharedir}/sounds/kamoso-shutter.wav

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Sat May 30 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add missing gstreamer-plugins-bad package requirement (boo#1172305)
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * --cmake warning
  * Don't set random caps
  * Let GStreamer create the device source
  * Improve how we list devices
  * Don't crash when the GstStructure is null
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Add copyright headers for QML files
  * Use URL with transport encryption
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Fix running qtvideosink_autotest after requiring >= ECM 5.38
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Bump frameworks dependency to 5.63
  * When in Desktop view, show a desktop-style toolbar with centered actions (kde#402948)
  * Use contextually-appropriate icon for GlobalDrawer handle button
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Follow KDE_APPLICATIONS_VERSION
  * Easier to read GstPointer
  * Properly un-mirror images
  * Allow to enable/disable the mirrored setting (kde#405309)
  * Remove apparently unused FindGLIB2
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Thu Jul  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Replace BuildDep on Qt5GStreamer with plain gstreamer-1.0
- Add kirigami2 runtime dep
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Don't leak gst structures
  * Add DesktopEntry to notifyrc
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix taking pictures when the pictures directories didn't exist (kde#404456)
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix compilation with -DQT_NO_URL_CAST_FROM_STRING and enable it.
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Only set the size when starting
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Use API for removing the toolbar
  * Fix minor EBN issues
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix crash when destroying a surface
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Simplify effect items code
  * Improve appstream summary and description
  * webcamcontrol: Solve crash when calling gst_element_set_state twice
  * Fix build against gst 1.14 (kde#392245)
  * Remove unused defines
  * Fix warning
  * Search for runtime components
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Fix qml warning
  * Unneedd identifier
  * Make sure we don't offer a null geometry
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * webcamcontrol: Solve crash when calling gst_element_set_state twice (kde#394881)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Sat Apr 21 2018 jengelh@inai.de
- Update description.
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Sun Apr  8 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.03.80.php
- Changes since 3.2.4:
  * Too many changes to list here
- Moved to KDE Applications
* Thu Aug  3 2017 wbauer@tmo.at
- Update to 3.2.4
  * Fix run with gstreamer 1.8
  * Don't crash if we run Kamoso without any webcams
* Sat Feb 18 2017 wbauer@tmo.at
- Update to 3.2.2
  * No changelog provided
- Own %%{_kf5_appstreamdir} on Leap 42.1 to fix build
* Fri Oct 28 2016 hrvoje.senjan@gmail.com
- Update to 3.2.1
  * No changelog provided
* Tue Jan  5 2016 hrvoje.senjan@gmail.com
- Update to 3.1.0:
  * Fixes some small usability issues with regards to the picture gallery.
- Changes since 3.0:
  * Now we’re using camerabin for the video capture (in contrast
    to using v4l2src directly).
  * Re-designed interface that integrates some really lean and
    meaningful animations and sorts the components so that we can
    get a simple, dialog-free UI.
  * Adopted the new Purpose technology that is seeing its light
    for the first time
* Fri May  1 2015 asterios.dramis@gmail.com
- Fix build in Tumbleweed (remove not needed anymore icons rename).
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 2.0.3~git20140916 from git:
  * GStreamer-1.0 API and QtGStreamer-1.2 support
  * Removed Nepomuk integration
- Drop patches merged upstream:
  icon_fix.patch, kamoso-2.0.2-fix_kipi_conflict.patch,
  fix_build_wih_older_libkipi.patch, GStreamer-1.patch,
  kamoso-2.0.2-libkipi-build-fix.patch, libkipi2.x_port.patch,
  make_about_dialog_work.patch and license_header.patch
* Thu Jul 24 2014 hrvoje.senjan@gmail.com
- Added GStreamer-1.patch to build with gstreamer 1.0 API
- Adjust BuildRequires accordingly
* Sun Dec 30 2012 asterios.dramis@gmail.com
- Updated kamoso-2.0.2-fix_kipi_conflict.patch to include the icon rename fix.
- Updated kamoso-2.0.2-libkipi-build-fix.patch based on upstream fix.
- Added the following upstream patches:
  * make_about_dialog_work.patch (Make the About dialog work)
  * icon_fix.patch (Use camera-web icon instead of webcamreceive)
  * libkipi2.x_port.patch (Initial port to libkipi-2.x)
  * license_header.patch (Add license header to newly added file)
  * fix_build_wih_older_libkipi.patch (Fix build for < libkipi-2)
* Mon Aug  6 2012 toddrme2178@gmail.com
- Fix building on KR49
* Wed Jul  4 2012 toddrme2178@gmail.com
- Fix qtgstreamer package naming
- Fix translation rpmlint warnings
* Fri Aug 26 2011 asterios.dramis@gmail.com
- Update to version 2.0.2.
- Spec file updates:
  * Changed License: to GPL-2.0+.
  * Added glib2-devel and gstreamer-0.10 in BuildRequires:.
* Sun Mar 20 2011 asterios.dramis@gmail.com
- Update to version 2.0beta1.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Summary:, Url:, Group: and %%description entries.
  * Removed kde4-filesystem and kdebase4-workspace-devel from Buildrequires:
    section (not needed).
  * Updated Requires: section (gstreamer, gstreamer-plugins-base and
    kipi-plugins).
  * Updates in %%install and %%files sections.
  * Removed kamoso-lang package (not packaged in this version).
* Wed Feb  2 2011 wstephenson@novell.com
- Kamoso 2.0alpha2
  * Take pictures
  * Upload pictures to Facebook
  * Record video
  * Upload videos to Youtube
  * Burst mode
  * Smoother thumbnails view
  * Fancy overlay icons to indicate what files are being uploaded
* Wed Feb  2 2011 wstephenson@novell.com
- Initial package, based on jospoortvliet's 1.0 version
